Functions
:::::::::

.. toctree::
   :caption: Functions
   :maxdepth: 2

   intro-Functions.rst
   FunctionDefinitions.rst
   FunctionInvocation.rst
   FunctionParameters.rst
   Returningavaluefromafunction.rst
   DecodingaFunction.rst
   TypeAnnotations.rst
   Afunctionthataccumulates.rst
   Variablesandparametersarelocal.rst
   GlobalVariables.rst
   Functionscancallotherfunctions.rst
   FlowofExecutionSummary.rst
   Printvsreturn.rst
   PassingMutableObjects.rst
   SideEffects.rst
   Glossary.rst
   Exercises.rst
   ChapterAssessment.rst
      
